==> django-privacy-policy-tools-0.0.1.tar.gz: django-privacy-policy-tools-0.0.1/privacy_policy_tools/translation.py <==

# Copyright (c) 2022 Josef Wachtler
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
This module handles the model translation. It registers models which have
content in multiple languages.
"""

from modeltranslation.translator import translator, TranslationOptions

from privacy_policy_tools.models import PrivacyPolicy


class PrivacyPolicyTranslationOptions(TranslationOptions):
    """
    Registers the fields of the PrivacyPolicy model for translation.
    """
    fields = ('title', 'text', )


translator.register(PrivacyPolicy, PrivacyPolicyTranslationOptions)

==> django-privacy-policy-tools-0.0.4.tar.gz: django-privacy-policy-tools-0.0.4/privacy_policy_tools/translation.py <==

# Copyright (c) 2022 Josef Wachtler
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
This module handles the model translation. It registers models which have
content in multiple languages.
"""

from modeltranslation.translator import translator, TranslationOptions

from privacy_policy_tools.models import PrivacyPolicy


class PrivacyPolicyTranslationOptions(TranslationOptions):
    """
    Registers the fields of the PrivacyPolicy model for translation.
    """
    fields = ('title', 'text', 'confirm_checkbox_text',
              'confirm_button_text')


translator.register(PrivacyPolicy, PrivacyPolicyTranslationOptions)
